@@ -42,6 +42,11 @@ class Policy(object):
         self.policy = policy
         self.exceptions = exceptions
 
+    def __repr__(self):
+        return '<Policy: %s except for %s>' % (self.policy, self.exceptions)
+
+    __str__ = __repr__
+
 class Permissions(object):
     """
     A nicer view onto Namespace/Tag/TagValue permissions
@@ -296,7 +301,7 @@ class readonly_tag_value(object):
     simple attribute.
     """
 
-    def __init__(self, tagpath, cached_attr=None):
+    def __init__(self, tagpath):
         self.tagpath = tagpath
 
     def __get__(self, instance, owner):
@@ -308,8 +313,16 @@ class tag_value(readonly_tag_value):
     simple attribute. With write support.
     """
 
-    def __set__(self, instance, value, valueType=None):
-        return instance.set(self.tagpath, value, valueType)
+    def __init__(self, tagpath, defaultType=None):
+        """
+        defaultType argument sets the default mime-type to be used when
+        PUTting the value
+        """
+        super(tag_value, self).__init__(tagpath)
+        self.defaultType = defaultType
+
+    def __set__(self, instance, value):
+        return instance.set(self.tagpath, value, self.defaultType)
 
 
 
@@ -459,9 +472,6 @@ class CollectionManager(object):
         for obj in resp.value[u'ids']:
             yield obj
 
-
-
-
 class tag_manager(tag_value):
 
     def __init__(self, tagpath, map_type=Object, manager_type=CollectionManager):
